@@ -151,3 +151,28 @@ test_that("create_data_random()", {
   )
 })
 
+# create data unfair ------------------------------------------------------
+
+# create dataset with obs
+test_that("create_data_unfair()", {
+  expect_equal(
+    nrow(create_data_churn(obs = 100)),
+    100
+  )
+})
+
+# create dataset is reproducible when using the same seed
+test_that("create_data_unfair()", {
+  expect_equal(
+    create_data_churn(obs = 100, seed = 1),
+    create_data_churn(obs = 100, seed = 1)
+  )
+})
+
+# add_id works
+test_that("create_data_unfair()", {
+  expect_true(
+    ncol(create_data_churn(obs = 100, add_id = TRUE)) ==
+      ncol(create_data_churn(obs = 100, add_id = FALSE)) + 1
+  )
+})
